Skip site navigation (1)Skip section navigation (2)
Date:      Thu, 6 Dec 2018 22:35:07 +0000 (UTC)
From:      John Baldwin <jhb@FreeBSD.org>
To:        src-committers@freebsd.org, svn-src-all@freebsd.org, svn-src-head@freebsd.org
Subject:   svn commit: r341656 - head/usr.bin/truss
Message-ID:  <201812062235.wB6MZ70E016140@repo.freebsd.org>

next in thread | raw e-mail | index | archive | help
Author: jhb
Date: Thu Dec  6 22:35:07 2018
New Revision: 341656
URL: https://svnweb.freebsd.org/changeset/base/341656

Log:
  Rename riscv64-freebsd.c to riscv-freebsd.c.
  
  This fixes truss when built as part of a riscv64sf world.  Additionally,
  if FreeBSD ever supports RV32 RISC-V most of this file can be used as-is
  just as a single file is used for all of the MIPS ABIs.
  
  Sponsored by:	DARPA

Added:
  head/usr.bin/truss/riscv-freebsd.c
     - copied, changed from r341655, head/usr.bin/truss/riscv64-freebsd.c
Deleted:
  head/usr.bin/truss/riscv64-freebsd.c

Copied and modified: head/usr.bin/truss/riscv-freebsd.c (from r341655, head/usr.bin/truss/riscv64-freebsd.c)
==============================================================================
--- head/usr.bin/truss/riscv64-freebsd.c	Thu Dec  6 21:52:40 2018	(r341655, copy source)
+++ head/usr.bin/truss/riscv-freebsd.c	Thu Dec  6 22:35:07 2018	(r341656)
@@ -26,7 +26,7 @@
 #include <sys/cdefs.h>
 __FBSDID("$FreeBSD$");
 
 /* FreeBSD/riscv64-specific system call handling. */
 
 #include <sys/ptrace.h>
 #include <sys/syscall.h>
@@ -41,7 +41,7 @@ __FBSDID("$FreeBSD$");
 #include "truss.h"
 
 static int
-riscv64_fetch_args(struct trussinfo *trussinfo, u_int narg)
+riscv_fetch_args(struct trussinfo *trussinfo, u_int narg)
 {
 	struct reg regs;
 	struct current_syscall *cs;
@@ -77,7 +77,7 @@ riscv64_fetch_args(struct trussinfo *trussinfo, u_int 
 }
 
 static int
-riscv64_fetch_retval(struct trussinfo *trussinfo, long *retval, int *errorp)
+riscv_fetch_retval(struct trussinfo *trussinfo, long *retval, int *errorp)
 {
 	struct reg regs;
 	lwpid_t tid;
@@ -94,13 +94,13 @@ riscv64_fetch_retval(struct trussinfo *trussinfo, long
 	return (0);
 }
 
-static struct procabi riscv64_freebsd = {
+static struct procabi riscv_freebsd = {
 	"FreeBSD ELF64",
 	SYSDECODE_ABI_FREEBSD,
-	riscv64_fetch_args,
-	riscv64_fetch_retval,
-	STAILQ_HEAD_INITIALIZER(riscv64_freebsd.extra_syscalls),
+	riscv_fetch_args,
+	riscv_fetch_retval,
+	STAILQ_HEAD_INITIALIZER(riscv_freebsd.extra_syscalls),
 	{ NULL }
 };
 
-PROCABI(riscv64_freebsd);
+PROCABI(riscv_freebsd);
@@ -26,7 +26,7 @@
 __FBSDID("$FreeBSD$");
 
-/* FreeBSD/riscv64-specific system call handling. */
+/* FreeBSD/riscv-specific system call handling. */
 
 #include <sys/ptrace.h>



Want to link to this message? Use this URL: <https://mail-archive.FreeBSD.org/cgi/mid.cgi?201812062235.wB6MZ70E016140>